# Changelog

All notable changes to this project will be documented in this file.


## v0.1.0 (2023-05-28)
- Initial release w/ basic functionality
    * Set logging for root logger by default
    * Allow configuring logging for other loggers
    * Load settings from a YAML file
    * Decorator to log print statements to a logger
    * Logfile handler to also log to a file
